import Box from '@mui/material/Box';
import { styled } from '@nuskin/foundation-theme';
import { NsButton, NsIcon, NsIconNameType, NsImage, NsTypography } from '..';

type NsMediumCardProps = {
    title: string;
    titleFontWeight?: 'bold' | 'normal' | 'light';
    subtitle: string;
    icon?: NsIconNameType;
    backgroundImageUrl: string;
    backgroundImageAlt: string;
    buttonVariant: 'text' | 'outlined' | 'contained';
    cardLink: { href: string; title: string };
};

const CardContainer = styled(Box)(() => {
    return {
        display: 'flex',
        flexDirection: 'column',
        position: 'relative',
        '.image': {
            width: '300px',
            height: '300px',
            objectFit: 'cover',
        },
        '.content': {
            display: 'flex',
            width: '300px',
            flexDirection: 'column',
        },
        '.subtitle': {
            fontSize: '16px',
            fontWeight: '400',
            marginTop: '10px',
        },
        '.title': {
            fontSize: '20px',
            marginTop: '10px',
        },
        '.action-link': {
            marginTop: '10px',
            fontSize: '14px',
            alignSelf: 'start',
        },
    };
});

export default function NsMediumCard({
    title,
    titleFontWeight,
    subtitle,
    backgroundImageUrl,
    backgroundImageAlt,
    cardLink,
    icon,
    buttonVariant,
}: NsMediumCardProps) {
    return (
        <CardContainer role="medium-card" component="div" data-testid="medium-card">
            <NsImage alt={backgroundImageAlt} src={backgroundImageUrl} className="image" />
            <div className="content">
                <NsTypography variant="h5" color="primary" className="title" weight={titleFontWeight}>
                    {title}
                </NsTypography>
                <article className="subtitle">{subtitle}</article>
                <NsButton
                    className="action-link"
                    variant={buttonVariant}
                    color="primary"
                    href={cardLink.href}
                    fullWidth={false}
                    endIcon={buttonVariant !== 'contained' ? <NsIcon className="icon" name={icon} /> : null}
                >
                    {cardLink.title}
                </NsButton>
            </div>
        </CardContainer>
    );
}
