import Box from '@mui/material/Box';
import { NsImage } from '../';
import { AdditionalProps } from '../common.types';
import { styled } from '@nuskin/foundation-theme';

type NsPostProps = {
    text: string;
    body: string;
    backgroundImageUrl: string;
    backgroundImageAlt: string;
} & AdditionalProps;

const CardContainer = styled(Box)(() => {
    return {
        backgroundClip: 'border-box',
        display: 'flex',
        flexDirection: 'column' as 'column', // https://github.com/cssinjs/jss/issues/1344
        wordWrap: 'break-word' as 'break-word',
        position: 'relative',
        overflow: 'hidden',
        height: 'auto',
        width: '200px',
        backgroundColor: '#fff',
        '.content': {
            padding: '10px',
            display: 'flex',
            flexDirection: 'column',
            minHeight: '150px',
            justifyContent: 'space-between',
        },
        '.body-title': {
            fontSize: '18px',
            marginBottom: '5px',
            fontWeight: 600,
        },
        '.body-text': {
            fontSize: '12px',
            color: '#8C8C8C',
            marginBottom: '5px',
        },
    };
});

const NsPost = ({ text, body, backgroundImageUrl, backgroundImageAlt, additionalProps }: NsPostProps) => {
    return (
        <CardContainer data-testid={additionalProps?.testid}>
            <div className="image">
                <NsImage height="auto" width="100%" alt={backgroundImageAlt} src={backgroundImageUrl} />
            </div>
            <div className="content">
                <article className="body-title">{text}</article>
                <article className="body-text">{body}</article>
            </div>
        </CardContainer>
    );
};
export default NsPost;
